/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

  GtkWidget *window;
  GtkWidget *notebook;

  GtkWidget *page0_cancel_button;
  GtkWidget *page0_next_button;
  GtkWidget *all_files_radiobutton;

  GtkWidget *settings_only_radiobutton;
  GtkWidget *system_admin_backup_radiobutton;
  GtkWidget *newfiles_only_checkbox_button;

  GtkWidget *cd_medium_radiobutton;
  GtkWidget *usb_medium_radiobutton;
  GtkWidget *email_medium_radiobutton;
  GtkWidget *ftp_medium_radiobutton;
  GtkWidget *home_directory_radiobutton;

  GtkWidget *page1_back_button;
  GtkWidget *page1_next_button;

  GtkWidget *page2_back_button;
  GtkWidget *page2_next_button;

  GtkWidget *page3_back_button;
  GtkWidget *page3_next_button;

  GtkWidget *page4_back_button;
  GtkWidget *page4_next_button;

  GtkWidget *page5_back_button;
  GtkWidget *page5_next_button;

  GtkWidget *page6_back_button;
  GtkWidget *page6_next_button;

  GtkWidget *page7_back_button;
  GtkWidget *page7_record_button;

  GtkWidget *ftp_server_entry;

  GtkWidget *backup_name_entry;
  GtkWidget *email_address_entry;

  GtkWidget *ftp_username_entry;
  GtkWidget *ftp_password_entry;
  GtkWidget *ftp_anonymous_login_checkbutton;

  GtkWidget *admin_home_backup_checkbutton;

  GtkWidget *admin_etc_backup_checkbutton;
  GtkWidget *admin_var_backup_checkbutton;

  GtkWidget *zip_compression_radiobutton;
  GtkWidget *tar_bz2_compression_radiobutton;
  GtkWidget *tar_gz_compression_radiobutton;

GtkWidget*
create_window (void)
{

  GtkWidget *vbox1;
  GtkWidget *hbox1;
  GtkWidget *image1;
  GtkWidget *label4;
  GtkWidget *label8;
  GtkWidget *hbuttonbox1;

  GtkWidget *alignment1;
  GtkWidget *hbox4;
  GtkWidget *image4;
  GtkWidget *label7;
  GtkWidget *vbox4;

  GSList *all_files_radiobutton_group = NULL;

  GtkWidget *label1;
  GtkWidget *vbox2;
  GtkWidget *hbox2;
  GtkWidget *image2;
  GtkWidget *label5;
  GtkWidget *label13;
  GtkWidget *vbox5;

  GSList *cd_medium_radiobutton_group = NULL;

  GtkWidget *hbuttonbox3;

  GtkWidget *alignment5;
  GtkWidget *hbox13;
  GtkWidget *image10;
  GtkWidget *label18;

  GtkWidget *alignment3;
  GtkWidget *hbox9;
  GtkWidget *image7;
  GtkWidget *label12;
  GtkWidget *label2;
  GtkWidget *vbox3;
  GtkWidget *hbox10;
  GtkWidget *image8;
  GtkWidget *label14;
  GtkWidget *label15;
  GtkWidget *hbox12;
  GtkWidget *label17;

  GtkWidget *hbuttonbox4;

  GtkWidget *alignment6;
  GtkWidget *hbox14;
  GtkWidget *image11;
  GtkWidget *label19;

  GtkWidget *alignment4;
  GtkWidget *hbox11;
  GtkWidget *image9;
  GtkWidget *label16;
  GtkWidget *label3;
  GtkWidget *vbox7;
  GtkWidget *hbox18;
  GtkWidget *image14;
  GtkWidget *label29;
  GtkWidget *label30;
  GtkWidget *hbox19;
  GtkWidget *label31;

  GtkWidget *hbuttonbox6;

  GtkWidget *alignment8;
  GtkWidget *hbox20;
  GtkWidget *image15;
  GtkWidget *label32;

  GtkWidget *alignment9;
  GtkWidget *hbox21;
  GtkWidget *image16;
  GtkWidget *label33;
  GtkWidget *label25;
  GtkWidget *vbox8;
  GtkWidget *hbox22;
  GtkWidget *image17;
  GtkWidget *label34;
  GtkWidget *label35;
  GtkWidget *hbox23;
  GtkWidget *label36;

  GtkWidget *hbuttonbox7;

  GtkWidget *alignment10;
  GtkWidget *hbox24;
  GtkWidget *image18;
  GtkWidget *label37;

  GtkWidget *alignment11;
  GtkWidget *hbox25;
  GtkWidget *image19;
  GtkWidget *label38;
  GtkWidget *hbox26;
  GtkWidget *label39;

  GtkWidget *hbox27;
  GtkWidget *label40;

  GtkWidget *label26;
  GtkWidget *vbox9;
  GtkWidget *hbox28;
  GtkWidget *image20;
  GtkWidget *label41;
  GtkWidget *label42;

  GtkWidget *label46;
  GtkWidget *hbuttonbox8;

  GtkWidget *alignment12;
  GtkWidget *hbox30;
  GtkWidget *image21;
  GtkWidget *label44;

  GtkWidget *alignment13;
  GtkWidget *hbox31;
  GtkWidget *image22;
  GtkWidget *label45;

  GtkWidget *label47;

  GtkWidget *label48;
  GtkWidget *label27;
  GtkWidget *vbox6;
  GtkWidget *hbox15;
  GtkWidget *image12;
  GtkWidget *label21;
  GtkWidget *label22;
  GtkWidget *hbuttonbox5;

  GtkWidget *alignment7;
  GtkWidget *hbox17;
  GtkWidget *image13;
  GtkWidget *label24;

  GtkWidget *alignment15;
  GtkWidget *hbox34;
  GtkWidget *image25;
  GtkWidget *label56;
  GtkWidget *vbox11;

  GSList *tar_gz_compression_radiobutton_group = NULL;
  GtkWidget *label53;

  GtkWidget *label54;

  GtkWidget *label55;
  GtkWidget *label20;
  GtkWidget *vbox10;
  GtkWidget *hbox32;
  GtkWidget *image23;
  GtkWidget *label50;
  GtkWidget *label51;
  GtkWidget *hbuttonbox9;

  GtkWidget *alignment14;
  GtkWidget *hbox33;
  GtkWidget *image24;
  GtkWidget *label52;

  GtkWidget *label49;

  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (window), _("Home User Backup"));
  gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER_ALWAYS);
  gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
  gtk_window_set_icon_name (GTK_WINDOW (window), "gtk-harddisk");

  notebook = gtk_notebook_new ();
  gtk_widget_show (notebook);
  gtk_container_add (GTK_CONTAINER (window), notebook);
  GTK_WIDGET_UNSET_FLAGS (notebook, GTK_CAN_FOCUS);
  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (notebook), vbox1);

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox1), 5);

  image1 = gtk_image_new_from_stock ("gtk-harddisk", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image1);
  gtk_box_pack_start (GTK_BOX (hbox1), image1, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image1), 30, 0);

  label4 = gtk_label_new (_("<span size=\"x-large\">Home User Backup</span>"));
  gtk_widget_show (label4);
  gtk_box_pack_start (GTK_BOX (hbox1), label4, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label4), TRUE);

  label8 = gtk_label_new (_("Welcome to Ubuntu Backup\n\nIt is recommended that you backup your files before\na critical data loss occurs. This will guide you to backup\nyour files on to a medium.\n\nPlease select the files you want to backup."));
  gtk_widget_show (label8);
  gtk_box_pack_start (GTK_BOX (vbox1), label8, FALSE, FALSE, 10);
  gtk_misc_set_padding (GTK_MISC (label8), 10, 0);

  hbuttonbox1 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox1);
  gtk_box_pack_end (GTK_BOX (vbox1), hbuttonbox1, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox1), 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox1), 10);

  page0_cancel_button = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (page0_cancel_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox1), page0_cancel_button);
  gtk_widget_set_size_request (page0_cancel_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page0_cancel_button, GTK_CAN_DEFAULT);

  page0_next_button = gtk_button_new ();
  gtk_widget_show (page0_next_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox1), page0_next_button);
  gtk_widget_set_size_request (page0_next_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page0_next_button, GTK_CAN_DEFAULT);

  alignment1 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment1);
  gtk_container_add (GTK_CONTAINER (page0_next_button), alignment1);

  hbox4 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox4);
  gtk_container_add (GTK_CONTAINER (alignment1), hbox4);

  image4 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image4);
  gtk_box_pack_start (GTK_BOX (hbox4), image4, FALSE, FALSE, 0);

  label7 = gtk_label_new_with_mnemonic (_("_Next"));
  gtk_widget_show (label7);
  gtk_box_pack_start (GTK_BOX (hbox4), label7, FALSE, FALSE, 0);

  vbox4 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox4);
  gtk_box_pack_start (GTK_BOX (vbox1), vbox4, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox4), 40);

  all_files_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Backup All My Files (Recommended)"));
  gtk_widget_show (all_files_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox4), all_files_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (all_files_radiobutton), all_files_radiobutton_group);
  all_files_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (all_files_radiobutton));

  settings_only_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Just My Desktop Settings"));
  gtk_widget_show (settings_only_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox4), settings_only_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (settings_only_radiobutton), all_files_radiobutton_group);
  all_files_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (settings_only_radiobutton));

  system_admin_backup_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("System Administrator Backup"));
  gtk_widget_show (system_admin_backup_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox4), system_admin_backup_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (system_admin_backup_radiobutton), all_files_radiobutton_group);
  all_files_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (system_admin_backup_radiobutton));

  newfiles_only_checkbox_button = gtk_check_button_new_with_mnemonic (_("Backup only new files."));
  gtk_widget_show (newfiles_only_checkbox_button);
  gtk_box_pack_start (GTK_BOX (vbox4), newfiles_only_checkbox_button, FALSE, FALSE, 10);

  label1 = gtk_label_new (_("label1"));
  gtk_widget_show (label1);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 0), label1);

  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox2);
  gtk_container_add (GTK_CONTAINER (notebook), vbox2);

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox2), 5);

  image2 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image2);
  gtk_box_pack_start (GTK_BOX (hbox2), image2, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image2), 30, 0);

  label5 = gtk_label_new (_("<span size=\"x-large\">Select A Backup Medium</span>"));
  gtk_widget_show (label5);
  gtk_box_pack_start (GTK_BOX (hbox2), label5, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label5), TRUE);

  label13 = gtk_label_new (_("Please Select an Storage medium where you\nwant to store your backup."));
  gtk_widget_show (label13);
  gtk_box_pack_start (GTK_BOX (vbox2), label13, FALSE, TRUE, 10);

  vbox5 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox5);
  gtk_box_pack_start (GTK_BOX (vbox2), vbox5, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox5), 40);

  cd_medium_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("CD-R/RW Recordable Disc"));
  gtk_widget_show (cd_medium_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox5), cd_medium_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (cd_medium_radiobutton), cd_medium_radiobutton_group);
  cd_medium_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (cd_medium_radiobutton));

  usb_medium_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("USB Storage Device"));
  gtk_widget_show (usb_medium_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox5), usb_medium_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (usb_medium_radiobutton), cd_medium_radiobutton_group);
  cd_medium_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (usb_medium_radiobutton));

  email_medium_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("E-Mail"));
  gtk_widget_show (email_medium_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox5), email_medium_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (email_medium_radiobutton), cd_medium_radiobutton_group);
  cd_medium_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (email_medium_radiobutton));

  ftp_medium_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("FTP Network Server"));
  gtk_widget_show (ftp_medium_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox5), ftp_medium_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (ftp_medium_radiobutton), cd_medium_radiobutton_group);
  cd_medium_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (ftp_medium_radiobutton));

  home_directory_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Home Directory"));
  gtk_widget_show (home_directory_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox5), home_directory_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (home_directory_radiobutton), cd_medium_radiobutton_group);
  cd_medium_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (home_directory_radiobutton));

  hbuttonbox3 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox3);
  gtk_box_pack_end (GTK_BOX (vbox2), hbuttonbox3, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox3), 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox3), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox3), 10);

  page1_back_button = gtk_button_new ();
  gtk_widget_show (page1_back_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox3), page1_back_button);
  gtk_widget_set_size_request (page1_back_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page1_back_button, GTK_CAN_DEFAULT);

  alignment5 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment5);
  gtk_container_add (GTK_CONTAINER (page1_back_button), alignment5);

  hbox13 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox13);
  gtk_container_add (GTK_CONTAINER (alignment5), hbox13);

  image10 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image10);
  gtk_box_pack_start (GTK_BOX (hbox13), image10, FALSE, FALSE, 0);

  label18 = gtk_label_new_with_mnemonic ("_Back");
  gtk_widget_show (label18);
  gtk_box_pack_start (GTK_BOX (hbox13), label18, FALSE, FALSE, 0);

  page1_next_button = gtk_button_new ();
  gtk_widget_show (page1_next_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox3), page1_next_button);
  gtk_widget_set_size_request (page1_next_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page1_next_button, GTK_CAN_DEFAULT);

  alignment3 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment3);
  gtk_container_add (GTK_CONTAINER (page1_next_button), alignment3);

  hbox9 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox9);
  gtk_container_add (GTK_CONTAINER (alignment3), hbox9);

  image7 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image7);
  gtk_box_pack_start (GTK_BOX (hbox9), image7, FALSE, FALSE, 0);

  label12 = gtk_label_new_with_mnemonic (_("_Next"));
  gtk_widget_show (label12);
  gtk_box_pack_start (GTK_BOX (hbox9), label12, FALSE, FALSE, 0);

  label2 = gtk_label_new (_("label2"));
  gtk_widget_show (label2);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 1), label2);

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox3);
  gtk_container_add (GTK_CONTAINER (notebook), vbox3);

  hbox10 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox10);
  gtk_box_pack_start (GTK_BOX (vbox3), hbox10, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox10), 5);

  image8 = gtk_image_new_from_stock ("gtk-save-as", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image8);
  gtk_box_pack_start (GTK_BOX (hbox10), image8, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image8), 30, 0);

  label14 = gtk_label_new (_("<span size=\"x-large\">Enter a Backup Label</span>"));
  gtk_widget_show (label14);
  gtk_box_pack_start (GTK_BOX (hbox10), label14, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label14), TRUE);

  label15 = gtk_label_new (_("Please Enter a Name for your Backup"));
  gtk_widget_show (label15);
  gtk_box_pack_start (GTK_BOX (vbox3), label15, FALSE, FALSE, 10);

  hbox12 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox12);
  gtk_box_pack_start (GTK_BOX (vbox3), hbox12, FALSE, FALSE, 10);
  gtk_container_set_border_width (GTK_CONTAINER (hbox12), 40);

  label17 = gtk_label_new (_("Backup Name: "));
  gtk_widget_show (label17);
  gtk_box_pack_start (GTK_BOX (hbox12), label17, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label17), 10, 0);

  backup_name_entry = gtk_entry_new ();
  gtk_widget_show (backup_name_entry);
  gtk_box_pack_start (GTK_BOX (hbox12), backup_name_entry, FALSE, FALSE, 0);
  gtk_widget_set_size_request (backup_name_entry, 250, -1);

  hbuttonbox4 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox4);
  gtk_box_pack_end (GTK_BOX (vbox3), hbuttonbox4, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox4), 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox4), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox4), 10);

  page2_back_button = gtk_button_new ();
  gtk_widget_show (page2_back_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox4), page2_back_button);
  gtk_widget_set_size_request (page2_back_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page2_back_button, GTK_CAN_DEFAULT);

  alignment6 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment6);
  gtk_container_add (GTK_CONTAINER (page2_back_button), alignment6);

  hbox14 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox14);
  gtk_container_add (GTK_CONTAINER (alignment6), hbox14);

  image11 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image11);
  gtk_box_pack_start (GTK_BOX (hbox14), image11, FALSE, FALSE, 0);

  label19 = gtk_label_new_with_mnemonic ("_Back");
  gtk_widget_show (label19);
  gtk_box_pack_start (GTK_BOX (hbox14), label19, FALSE, FALSE, 0);

  page2_next_button = gtk_button_new ();
  gtk_widget_show (page2_next_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox4), page2_next_button);
  gtk_widget_set_size_request (page2_next_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page2_next_button, GTK_CAN_DEFAULT);

  alignment4 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment4);
  gtk_container_add (GTK_CONTAINER (page2_next_button), alignment4);

  hbox11 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox11);
  gtk_container_add (GTK_CONTAINER (alignment4), hbox11);

  image9 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image9);
  gtk_box_pack_start (GTK_BOX (hbox11), image9, FALSE, FALSE, 0);

  label16 = gtk_label_new_with_mnemonic (_("_Next"));
  gtk_widget_show (label16);
  gtk_box_pack_start (GTK_BOX (hbox11), label16, FALSE, FALSE, 0);

  label3 = gtk_label_new (_("label3"));
  gtk_widget_show (label3);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 2), label3);

  vbox7 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox7);
  gtk_container_add (GTK_CONTAINER (notebook), vbox7);

  hbox18 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox18);
  gtk_box_pack_start (GTK_BOX (vbox7), hbox18, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox18), 5);

  image14 = gtk_image_new_from_icon_name ("stock_mail-send", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image14);
  gtk_box_pack_start (GTK_BOX (hbox18), image14, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image14), 30, 0);

  label29 = gtk_label_new (_("<span size=\"x-large\">Enter Email Address</span>"));
  gtk_widget_show (label29);
  gtk_box_pack_start (GTK_BOX (hbox18), label29, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label29), TRUE);

  label30 = gtk_label_new (_("Please enter the e-mail address where you would \nlike to send your files as an attachment."));
  gtk_widget_show (label30);
  gtk_box_pack_start (GTK_BOX (vbox7), label30, FALSE, FALSE, 10);

  hbox19 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox19);
  gtk_box_pack_start (GTK_BOX (vbox7), hbox19, FALSE, FALSE, 10);
  gtk_container_set_border_width (GTK_CONTAINER (hbox19), 40);

  label31 = gtk_label_new (_("Email Address: "));
  gtk_widget_show (label31);
  gtk_box_pack_start (GTK_BOX (hbox19), label31, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label31), 10, 0);

  email_address_entry = gtk_entry_new ();
  gtk_widget_show (email_address_entry);
  gtk_box_pack_start (GTK_BOX (hbox19), email_address_entry, FALSE, FALSE, 0);
  gtk_widget_set_size_request (email_address_entry, 250, -1);

  hbuttonbox6 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox6);
  gtk_box_pack_end (GTK_BOX (vbox7), hbuttonbox6, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox6), 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox6), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox6), 10);

  page3_back_button = gtk_button_new ();
  gtk_widget_show (page3_back_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox6), page3_back_button);
  gtk_widget_set_size_request (page3_back_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page3_back_button, GTK_CAN_DEFAULT);

  alignment8 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment8);
  gtk_container_add (GTK_CONTAINER (page3_back_button), alignment8);

  hbox20 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox20);
  gtk_container_add (GTK_CONTAINER (alignment8), hbox20);

  image15 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image15);
  gtk_box_pack_start (GTK_BOX (hbox20), image15, FALSE, FALSE, 0);

  label32 = gtk_label_new_with_mnemonic ("_Back");
  gtk_widget_show (label32);
  gtk_box_pack_start (GTK_BOX (hbox20), label32, FALSE, FALSE, 0);

  page3_next_button = gtk_button_new ();
  gtk_widget_show (page3_next_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox6), page3_next_button);
  gtk_widget_set_size_request (page3_next_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page3_next_button, GTK_CAN_DEFAULT);

  alignment9 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment9);
  gtk_container_add (GTK_CONTAINER (page3_next_button), alignment9);

  hbox21 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox21);
  gtk_container_add (GTK_CONTAINER (alignment9), hbox21);

  image16 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image16);
  gtk_box_pack_start (GTK_BOX (hbox21), image16, FALSE, FALSE, 0);

  label33 = gtk_label_new_with_mnemonic (_("_Next"));
  gtk_widget_show (label33);
  gtk_box_pack_start (GTK_BOX (hbox21), label33, FALSE, FALSE, 0);

  label25 = gtk_label_new (_("label25"));
  gtk_widget_show (label25);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 3), label25);

  vbox8 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox8);
  gtk_container_add (GTK_CONTAINER (notebook), vbox8);

  hbox22 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox22);
  gtk_box_pack_start (GTK_BOX (vbox8), hbox22, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox22), 5);

  image17 = gtk_image_new_from_icon_name ("gtk-network", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image17);
  gtk_box_pack_start (GTK_BOX (hbox22), image17, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image17), 30, 0);

  label34 = gtk_label_new (_("<span size=\"x-large\">Enter FTP Server Information</span>"));
  gtk_widget_show (label34);
  gtk_box_pack_start (GTK_BOX (hbox22), label34, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label34), TRUE);

  label35 = gtk_label_new (_("Please enter the FTP server address where you would \nlike to send your files, as well as the user accounts\nneeded by the server."));
  gtk_widget_show (label35);
  gtk_box_pack_start (GTK_BOX (vbox8), label35, FALSE, FALSE, 10);

  hbox23 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox23);
  gtk_box_pack_start (GTK_BOX (vbox8), hbox23, FALSE, FALSE, 0);

  label36 = gtk_label_new (_("FTP Server Address:  FTP://"));
  gtk_widget_show (label36);
  gtk_box_pack_start (GTK_BOX (hbox23), label36, FALSE, FALSE, 0);
  gtk_widget_set_size_request (label36, 190, -1);
  gtk_misc_set_padding (GTK_MISC (label36), 10, 0);

  ftp_server_entry = gtk_entry_new ();
  gtk_widget_show (ftp_server_entry);
  gtk_box_pack_start (GTK_BOX (hbox23), ftp_server_entry, FALSE, FALSE, 0);
  gtk_widget_set_size_request (ftp_server_entry, 250, -1);

  hbuttonbox7 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox7);
  gtk_box_pack_end (GTK_BOX (vbox8), hbuttonbox7, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox7), 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox7), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox7), 10);

  page4_back_button = gtk_button_new ();
  gtk_widget_show (page4_back_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox7), page4_back_button);
  gtk_widget_set_size_request (page4_back_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page4_back_button, GTK_CAN_DEFAULT);

  alignment10 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment10);
  gtk_container_add (GTK_CONTAINER (page4_back_button), alignment10);

  hbox24 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox24);
  gtk_container_add (GTK_CONTAINER (alignment10), hbox24);

  image18 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image18);
  gtk_box_pack_start (GTK_BOX (hbox24), image18, FALSE, FALSE, 0);

  label37 = gtk_label_new_with_mnemonic ("_Back");
  gtk_widget_show (label37);
  gtk_box_pack_start (GTK_BOX (hbox24), label37, FALSE, FALSE, 0);

  page4_next_button = gtk_button_new ();
  gtk_widget_show (page4_next_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox7), page4_next_button);
  gtk_widget_set_size_request (page4_next_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page4_next_button, GTK_CAN_DEFAULT);

  alignment11 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment11);
  gtk_container_add (GTK_CONTAINER (page4_next_button), alignment11);

  hbox25 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox25);
  gtk_container_add (GTK_CONTAINER (alignment11), hbox25);

  image19 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image19);
  gtk_box_pack_start (GTK_BOX (hbox25), image19, FALSE, FALSE, 0);

  label38 = gtk_label_new_with_mnemonic (_("_Next"));
  gtk_widget_show (label38);
  gtk_box_pack_start (GTK_BOX (hbox25), label38, FALSE, FALSE, 0);

  hbox26 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox26);
  gtk_box_pack_start (GTK_BOX (vbox8), hbox26, FALSE, FALSE, 0);

  label39 = gtk_label_new (_("Username"));
  gtk_widget_show (label39);
  gtk_box_pack_start (GTK_BOX (hbox26), label39, FALSE, FALSE, 0);
  gtk_widget_set_size_request (label39, 190, -1);
  gtk_misc_set_padding (GTK_MISC (label39), 10, 0);

  ftp_username_entry = gtk_entry_new ();
  gtk_widget_show (ftp_username_entry);
  gtk_box_pack_start (GTK_BOX (hbox26), ftp_username_entry, FALSE, FALSE, 0);
  gtk_widget_set_size_request (ftp_username_entry, 250, -1);

  hbox27 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox27);
  gtk_box_pack_start (GTK_BOX (vbox8), hbox27, FALSE, FALSE, 0);

  label40 = gtk_label_new (_("Password: "));
  gtk_widget_show (label40);
  gtk_box_pack_start (GTK_BOX (hbox27), label40, FALSE, FALSE, 0);
  gtk_widget_set_size_request (label40, 190, -1);
  gtk_misc_set_padding (GTK_MISC (label40), 10, 0);

  ftp_password_entry = gtk_entry_new ();
  gtk_widget_show (ftp_password_entry);
  gtk_box_pack_start (GTK_BOX (hbox27), ftp_password_entry, FALSE, FALSE, 0);
  gtk_widget_set_size_request (ftp_password_entry, 250, -1);
  gtk_entry_set_visibility (GTK_ENTRY (ftp_password_entry), FALSE);
  gtk_entry_set_invisible_char (GTK_ENTRY (ftp_password_entry), 9679);

  ftp_anonymous_login_checkbutton = gtk_check_button_new_with_mnemonic (_("Login as Anonymous"));
  gtk_widget_show (ftp_anonymous_login_checkbutton);
  gtk_box_pack_start (GTK_BOX (vbox8), ftp_anonymous_login_checkbutton, FALSE, FALSE, 10);
  gtk_container_set_border_width (GTK_CONTAINER (ftp_anonymous_login_checkbutton), 20);

  label26 = gtk_label_new (_("label26"));
  gtk_widget_show (label26);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 4), label26);

  vbox9 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox9);
  gtk_container_add (GTK_CONTAINER (notebook), vbox9);

  hbox28 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox28);
  gtk_box_pack_start (GTK_BOX (vbox9), hbox28, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox28), 5);

  image20 = gtk_image_new_from_icon_name ("gnome-system", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image20);
  gtk_box_pack_start (GTK_BOX (hbox28), image20, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image20), 30, 0);

  label41 = gtk_label_new (_("<span size=\"x-large\">Select System Files to Backup</span>"));
  gtk_widget_show (label41);
  gtk_box_pack_start (GTK_BOX (hbox28), label41, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label41), TRUE);

  label42 = gtk_label_new (_("System Administration Backup requires system password.\nYou will be asked to supply a system password later.\n\nPlease select the directories you want to backup. "));
  gtk_widget_show (label42);
  gtk_box_pack_start (GTK_BOX (vbox9), label42, FALSE, FALSE, 10);

  admin_home_backup_checkbutton = gtk_check_button_new_with_mnemonic (_("All User's Home Directories"));
  gtk_widget_show (admin_home_backup_checkbutton);
  gtk_box_pack_start (GTK_BOX (vbox9), admin_home_backup_checkbutton, FALSE, FALSE, 10);

  label46 = gtk_label_new (_("Backup all user's data and settings."));
  gtk_widget_show (label46);
  gtk_box_pack_start (GTK_BOX (vbox9), label46, FALSE, FALSE, 0);

  hbuttonbox8 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox8);
  gtk_box_pack_end (GTK_BOX (vbox9), hbuttonbox8, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox8), 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox8), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox8), 10);

  page5_back_button = gtk_button_new ();
  gtk_widget_show (page5_back_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox8), page5_back_button);
  gtk_widget_set_size_request (page5_back_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page5_back_button, GTK_CAN_DEFAULT);

  alignment12 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment12);
  gtk_container_add (GTK_CONTAINER (page5_back_button), alignment12);

  hbox30 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox30);
  gtk_container_add (GTK_CONTAINER (alignment12), hbox30);

  image21 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image21);
  gtk_box_pack_start (GTK_BOX (hbox30), image21, FALSE, FALSE, 0);

  label44 = gtk_label_new_with_mnemonic ("_Back");
  gtk_widget_show (label44);
  gtk_box_pack_start (GTK_BOX (hbox30), label44, FALSE, FALSE, 0);

  page5_next_button = gtk_button_new ();
  gtk_widget_show (page5_next_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox8), page5_next_button);
  gtk_widget_set_size_request (page5_next_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page5_next_button, GTK_CAN_DEFAULT);

  alignment13 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment13);
  gtk_container_add (GTK_CONTAINER (page5_next_button), alignment13);

  hbox31 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox31);
  gtk_container_add (GTK_CONTAINER (alignment13), hbox31);

  image22 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image22);
  gtk_box_pack_start (GTK_BOX (hbox31), image22, FALSE, FALSE, 0);

  label45 = gtk_label_new_with_mnemonic (_("_Next"));
  gtk_widget_show (label45);
  gtk_box_pack_start (GTK_BOX (hbox31), label45, FALSE, FALSE, 0);

  admin_etc_backup_checkbutton = gtk_check_button_new_with_mnemonic (_("System Configurations"));
  gtk_widget_show (admin_etc_backup_checkbutton);
  gtk_box_pack_start (GTK_BOX (vbox9), admin_etc_backup_checkbutton, FALSE, FALSE, 10);

  label47 = gtk_label_new (_("Backup the system-wide configurations \nand data."));
  gtk_widget_show (label47);
  gtk_box_pack_start (GTK_BOX (vbox9), label47, FALSE, FALSE, 0);

  admin_var_backup_checkbutton = gtk_check_button_new_with_mnemonic (_("Variable Files"));
  gtk_widget_show (admin_var_backup_checkbutton);
  gtk_box_pack_start (GTK_BOX (vbox9), admin_var_backup_checkbutton, FALSE, FALSE, 10);

  label48 = gtk_label_new (_("Backup log files, internet cache's \nand package manager cache's."));
  gtk_widget_show (label48);
  gtk_box_pack_start (GTK_BOX (vbox9), label48, FALSE, FALSE, 0);

  label27 = gtk_label_new (_("label27"));
  gtk_widget_show (label27);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 5), label27);

  vbox6 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox6);
  gtk_container_add (GTK_CONTAINER (notebook), vbox6);

  hbox15 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox15);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox15, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox15), 5);

  image12 = gtk_image_new_from_icon_name ("package-x-generic", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image12);
  gtk_box_pack_start (GTK_BOX (hbox15), image12, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image12), 30, 0);

  label21 = gtk_label_new (_("<span size=\"x-large\">Select a Compression Method</span>"));
  gtk_widget_show (label21);
  gtk_box_pack_start (GTK_BOX (hbox15), label21, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label21), TRUE);

  label22 = gtk_label_new (_("Please select what compression method we\nare going to use for the backups."));
  gtk_widget_show (label22);
  gtk_box_pack_start (GTK_BOX (vbox6), label22, FALSE, FALSE, 10);

  hbuttonbox5 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox5);
  gtk_box_pack_end (GTK_BOX (vbox6), hbuttonbox5, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox5), 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox5), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox5), 10);

  page6_back_button = gtk_button_new ();
  gtk_widget_show (page6_back_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox5), page6_back_button);
  gtk_widget_set_size_request (page6_back_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page6_back_button, GTK_CAN_DEFAULT);

  alignment7 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment7);
  gtk_container_add (GTK_CONTAINER (page6_back_button), alignment7);

  hbox17 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox17);
  gtk_container_add (GTK_CONTAINER (alignment7), hbox17);

  image13 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image13);
  gtk_box_pack_start (GTK_BOX (hbox17), image13, FALSE, FALSE, 0);

  label24 = gtk_label_new_with_mnemonic ("_Back");
  gtk_widget_show (label24);
  gtk_box_pack_start (GTK_BOX (hbox17), label24, FALSE, FALSE, 0);

  page6_next_button = gtk_button_new ();
  gtk_widget_show (page6_next_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox5), page6_next_button);
  gtk_widget_set_size_request (page6_next_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page6_next_button, GTK_CAN_DEFAULT);

  alignment15 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment15);
  gtk_container_add (GTK_CONTAINER (page6_next_button), alignment15);

  hbox34 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox34);
  gtk_container_add (GTK_CONTAINER (alignment15), hbox34);

  image25 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image25);
  gtk_box_pack_start (GTK_BOX (hbox34), image25, FALSE, FALSE, 0);

  label56 = gtk_label_new_with_mnemonic ("_Next");
  gtk_widget_show (label56);
  gtk_box_pack_start (GTK_BOX (hbox34), label56, FALSE, FALSE, 0);

  vbox11 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox11);
  gtk_box_pack_start (GTK_BOX (vbox6), vbox11, TRUE, TRUE, 0);

  tar_gz_compression_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Use .tar.gz Compression"));
  gtk_widget_show (tar_gz_compression_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox11), tar_gz_compression_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (tar_gz_compression_radiobutton), tar_gz_compression_radiobutton_group);
  tar_gz_compression_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (tar_gz_compression_radiobutton));

  label53 = gtk_label_new (_("This is the standard compression for most computers that use \nUbuntu Linux"));
  gtk_widget_show (label53);
  gtk_box_pack_start (GTK_BOX (vbox11), label53, FALSE, FALSE, 10);

  zip_compression_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Use .zip Compression"));
  gtk_widget_show (zip_compression_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox11), zip_compression_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (zip_compression_radiobutton), tar_gz_compression_radiobutton_group);
  tar_gz_compression_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (zip_compression_radiobutton));

  label54 = gtk_label_new (_("Use ZIP compression if your going to open your backup\nfiles in other computers that doesn't have Ubuntu Linux installed."));
  gtk_widget_show (label54);
  gtk_box_pack_start (GTK_BOX (vbox11), label54, FALSE, FALSE, 10);

  tar_bz2_compression_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Use .tar.bz2 Compression"));
  gtk_widget_show (tar_bz2_compression_radiobutton);
  gtk_box_pack_start (GTK_BOX (vbox11), tar_bz2_compression_radiobutton, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (tar_bz2_compression_radiobutton), tar_gz_compression_radiobutton_group);
  tar_gz_compression_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (tar_bz2_compression_radiobutton));

  label55 = gtk_label_new (_("This adds more compression ability to your backup files but is\nmuch slower."));
  gtk_widget_show (label55);
  gtk_box_pack_start (GTK_BOX (vbox11), label55, FALSE, FALSE, 10);

  label20 = gtk_label_new (_("label20"));
  gtk_widget_show (label20);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 6), label20);

  vbox10 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox10);
  gtk_container_add (GTK_CONTAINER (notebook), vbox10);

  hbox32 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox32);
  gtk_box_pack_start (GTK_BOX (vbox10), hbox32, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox32), 5);

  image23 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image23);
  gtk_box_pack_start (GTK_BOX (hbox32), image23, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image23), 30, 0);

  label50 = gtk_label_new (_("<span size=\"x-large\">Ready to Backup</span>"));
  gtk_widget_show (label50);
  gtk_box_pack_start (GTK_BOX (hbox32), label50, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label50), TRUE);

  label51 = gtk_label_new (_("All Set! we are now going to backup your files. \n\nPlease click the \"Record\" button to proceed."));
  gtk_widget_show (label51);
  gtk_box_pack_start (GTK_BOX (vbox10), label51, FALSE, FALSE, 10);

  hbuttonbox9 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox9);
  gtk_box_pack_end (GTK_BOX (vbox10), hbuttonbox9, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox9), 10);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox9), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox9), 10);

  page7_back_button = gtk_button_new ();
  gtk_widget_show (page7_back_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox9), page7_back_button);
  gtk_widget_set_size_request (page7_back_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page7_back_button, GTK_CAN_DEFAULT);

  alignment14 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment14);
  gtk_container_add (GTK_CONTAINER (page7_back_button), alignment14);

  hbox33 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox33);
  gtk_container_add (GTK_CONTAINER (alignment14), hbox33);

  image24 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image24);
  gtk_box_pack_start (GTK_BOX (hbox33), image24, FALSE, FALSE, 0);

  label52 = gtk_label_new_with_mnemonic ("_Back");
  gtk_widget_show (label52);
  gtk_box_pack_start (GTK_BOX (hbox33), label52, FALSE, FALSE, 0);

  page7_record_button = gtk_button_new_from_stock ("gtk-media-record");
  gtk_widget_show (page7_record_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox9), page7_record_button);
  gtk_widget_set_size_request (page7_record_button, 80, 34);
  GTK_WIDGET_SET_FLAGS (page7_record_button, GTK_CAN_DEFAULT);

  label49 = gtk_label_new (_("label49"));
  gtk_widget_show (label49);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 7), label49);

  g_signal_connect ((gpointer) window, "destroy",
                    G_CALLBACK (on_window_destroy),
                    NULL);
  g_signal_connect ((gpointer) page0_cancel_button, "clicked",
                    G_CALLBACK (on_page0_cancel_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page0_next_button, "clicked",
                    G_CALLBACK (on_page0_next_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page1_back_button, "clicked",
                    G_CALLBACK (on_page1_back_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page1_next_button, "clicked",
                    G_CALLBACK (on_page1_next_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page2_back_button, "clicked",
                    G_CALLBACK (on_page2_back_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page2_next_button, "clicked",
                    G_CALLBACK (on_page2_next_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page3_back_button, "clicked",
                    G_CALLBACK (on_page3_back_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page3_next_button, "clicked",
                    G_CALLBACK (on_page3_next_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page4_back_button, "clicked",
                    G_CALLBACK (on_page4_back_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page4_next_button, "clicked",
                    G_CALLBACK (on_page4_next_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page5_back_button, "clicked",
                    G_CALLBACK (on_page5_back_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page5_next_button, "clicked",
                    G_CALLBACK (on_page5_next_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page6_back_button, "clicked",
                    G_CALLBACK (on_page6_back_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page6_next_button, "clicked",
                    G_CALLBACK (on_page6_next_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page7_back_button, "clicked",
                    G_CALLBACK (on_page7_back_button_clicked),
                    NULL);
  g_signal_connect ((gpointer) page7_record_button, "clicked",
                    G_CALLBACK (on_page7_record_button_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window, window, "window");
  GLADE_HOOKUP_OBJECT (window, notebook, "notebook");
  GLADE_HOOKUP_OBJECT (window, vbox1, "vbox1");
  GLADE_HOOKUP_OBJECT (window, hbox1, "hbox1");
  GLADE_HOOKUP_OBJECT (window, image1, "image1");
  GLADE_HOOKUP_OBJECT (window, label4, "label4");
  GLADE_HOOKUP_OBJECT (window, label8, "label8");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox1, "hbuttonbox1");
  GLADE_HOOKUP_OBJECT (window, page0_cancel_button, "page0_cancel_button");
  GLADE_HOOKUP_OBJECT (window, page0_next_button, "page0_next_button");
  GLADE_HOOKUP_OBJECT (window, alignment1, "alignment1");
  GLADE_HOOKUP_OBJECT (window, hbox4, "hbox4");
  GLADE_HOOKUP_OBJECT (window, image4, "image4");
  GLADE_HOOKUP_OBJECT (window, label7, "label7");
  GLADE_HOOKUP_OBJECT (window, vbox4, "vbox4");
  GLADE_HOOKUP_OBJECT (window, all_files_radiobutton, "all_files_radiobutton");
  GLADE_HOOKUP_OBJECT (window, settings_only_radiobutton, "settings_only_radiobutton");
  GLADE_HOOKUP_OBJECT (window, system_admin_backup_radiobutton, "system_admin_backup_radiobutton");
  GLADE_HOOKUP_OBJECT (window, newfiles_only_checkbox_button, "newfiles_only_checkbox_button");
  GLADE_HOOKUP_OBJECT (window, label1, "label1");
  GLADE_HOOKUP_OBJECT (window, vbox2, "vbox2");
  GLADE_HOOKUP_OBJECT (window, hbox2, "hbox2");
  GLADE_HOOKUP_OBJECT (window, image2, "image2");
  GLADE_HOOKUP_OBJECT (window, label5, "label5");
  GLADE_HOOKUP_OBJECT (window, label13, "label13");
  GLADE_HOOKUP_OBJECT (window, vbox5, "vbox5");
  GLADE_HOOKUP_OBJECT (window, cd_medium_radiobutton, "cd_medium_radiobutton");
  GLADE_HOOKUP_OBJECT (window, usb_medium_radiobutton, "usb_medium_radiobutton");
  GLADE_HOOKUP_OBJECT (window, email_medium_radiobutton, "email_medium_radiobutton");
  GLADE_HOOKUP_OBJECT (window, ftp_medium_radiobutton, "ftp_medium_radiobutton");
  GLADE_HOOKUP_OBJECT (window, home_directory_radiobutton, "home_directory_radiobutton");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox3, "hbuttonbox3");
  GLADE_HOOKUP_OBJECT (window, page1_back_button, "page1_back_button");
  GLADE_HOOKUP_OBJECT (window, alignment5, "alignment5");
  GLADE_HOOKUP_OBJECT (window, hbox13, "hbox13");
  GLADE_HOOKUP_OBJECT (window, image10, "image10");
  GLADE_HOOKUP_OBJECT (window, label18, "label18");
  GLADE_HOOKUP_OBJECT (window, page1_next_button, "page1_next_button");
  GLADE_HOOKUP_OBJECT (window, alignment3, "alignment3");
  GLADE_HOOKUP_OBJECT (window, hbox9, "hbox9");
  GLADE_HOOKUP_OBJECT (window, image7, "image7");
  GLADE_HOOKUP_OBJECT (window, label12, "label12");
  GLADE_HOOKUP_OBJECT (window, label2, "label2");
  GLADE_HOOKUP_OBJECT (window, vbox3, "vbox3");
  GLADE_HOOKUP_OBJECT (window, hbox10, "hbox10");
  GLADE_HOOKUP_OBJECT (window, image8, "image8");
  GLADE_HOOKUP_OBJECT (window, label14, "label14");
  GLADE_HOOKUP_OBJECT (window, label15, "label15");
  GLADE_HOOKUP_OBJECT (window, hbox12, "hbox12");
  GLADE_HOOKUP_OBJECT (window, label17, "label17");
  GLADE_HOOKUP_OBJECT (window, backup_name_entry, "backup_name_entry");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox4, "hbuttonbox4");
  GLADE_HOOKUP_OBJECT (window, page2_back_button, "page2_back_button");
  GLADE_HOOKUP_OBJECT (window, alignment6, "alignment6");
  GLADE_HOOKUP_OBJECT (window, hbox14, "hbox14");
  GLADE_HOOKUP_OBJECT (window, image11, "image11");
  GLADE_HOOKUP_OBJECT (window, label19, "label19");
  GLADE_HOOKUP_OBJECT (window, page2_next_button, "page2_next_button");
  GLADE_HOOKUP_OBJECT (window, alignment4, "alignment4");
  GLADE_HOOKUP_OBJECT (window, hbox11, "hbox11");
  GLADE_HOOKUP_OBJECT (window, image9, "image9");
  GLADE_HOOKUP_OBJECT (window, label16, "label16");
  GLADE_HOOKUP_OBJECT (window, label3, "label3");
  GLADE_HOOKUP_OBJECT (window, vbox7, "vbox7");
  GLADE_HOOKUP_OBJECT (window, hbox18, "hbox18");
  GLADE_HOOKUP_OBJECT (window, image14, "image14");
  GLADE_HOOKUP_OBJECT (window, label29, "label29");
  GLADE_HOOKUP_OBJECT (window, label30, "label30");
  GLADE_HOOKUP_OBJECT (window, hbox19, "hbox19");
  GLADE_HOOKUP_OBJECT (window, label31, "label31");
  GLADE_HOOKUP_OBJECT (window, email_address_entry, "email_address_entry");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox6, "hbuttonbox6");
  GLADE_HOOKUP_OBJECT (window, page3_back_button, "page3_back_button");
  GLADE_HOOKUP_OBJECT (window, alignment8, "alignment8");
  GLADE_HOOKUP_OBJECT (window, hbox20, "hbox20");
  GLADE_HOOKUP_OBJECT (window, image15, "image15");
  GLADE_HOOKUP_OBJECT (window, label32, "label32");
  GLADE_HOOKUP_OBJECT (window, page3_next_button, "page3_next_button");
  GLADE_HOOKUP_OBJECT (window, alignment9, "alignment9");
  GLADE_HOOKUP_OBJECT (window, hbox21, "hbox21");
  GLADE_HOOKUP_OBJECT (window, image16, "image16");
  GLADE_HOOKUP_OBJECT (window, label33, "label33");
  GLADE_HOOKUP_OBJECT (window, label25, "label25");
  GLADE_HOOKUP_OBJECT (window, vbox8, "vbox8");
  GLADE_HOOKUP_OBJECT (window, hbox22, "hbox22");
  GLADE_HOOKUP_OBJECT (window, image17, "image17");
  GLADE_HOOKUP_OBJECT (window, label34, "label34");
  GLADE_HOOKUP_OBJECT (window, label35, "label35");
  GLADE_HOOKUP_OBJECT (window, hbox23, "hbox23");
  GLADE_HOOKUP_OBJECT (window, label36, "label36");
  GLADE_HOOKUP_OBJECT (window, ftp_server_entry, "ftp_server_entry");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox7, "hbuttonbox7");
  GLADE_HOOKUP_OBJECT (window, page4_back_button, "page4_back_button");
  GLADE_HOOKUP_OBJECT (window, alignment10, "alignment10");
  GLADE_HOOKUP_OBJECT (window, hbox24, "hbox24");
  GLADE_HOOKUP_OBJECT (window, image18, "image18");
  GLADE_HOOKUP_OBJECT (window, label37, "label37");
  GLADE_HOOKUP_OBJECT (window, page4_next_button, "page4_next_button");
  GLADE_HOOKUP_OBJECT (window, alignment11, "alignment11");
  GLADE_HOOKUP_OBJECT (window, hbox25, "hbox25");
  GLADE_HOOKUP_OBJECT (window, image19, "image19");
  GLADE_HOOKUP_OBJECT (window, label38, "label38");
  GLADE_HOOKUP_OBJECT (window, hbox26, "hbox26");
  GLADE_HOOKUP_OBJECT (window, label39, "label39");
  GLADE_HOOKUP_OBJECT (window, ftp_username_entry, "ftp_username_entry");
  GLADE_HOOKUP_OBJECT (window, hbox27, "hbox27");
  GLADE_HOOKUP_OBJECT (window, label40, "label40");
  GLADE_HOOKUP_OBJECT (window, ftp_password_entry, "ftp_password_entry");
  GLADE_HOOKUP_OBJECT (window, ftp_anonymous_login_checkbutton, "ftp_anonymous_login_checkbutton");
  GLADE_HOOKUP_OBJECT (window, label26, "label26");
  GLADE_HOOKUP_OBJECT (window, vbox9, "vbox9");
  GLADE_HOOKUP_OBJECT (window, hbox28, "hbox28");
  GLADE_HOOKUP_OBJECT (window, image20, "image20");
  GLADE_HOOKUP_OBJECT (window, label41, "label41");
  GLADE_HOOKUP_OBJECT (window, label42, "label42");
  GLADE_HOOKUP_OBJECT (window, admin_home_backup_checkbutton, "admin_home_backup_checkbutton");
  GLADE_HOOKUP_OBJECT (window, label46, "label46");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox8, "hbuttonbox8");
  GLADE_HOOKUP_OBJECT (window, page5_back_button, "page5_back_button");
  GLADE_HOOKUP_OBJECT (window, alignment12, "alignment12");
  GLADE_HOOKUP_OBJECT (window, hbox30, "hbox30");
  GLADE_HOOKUP_OBJECT (window, image21, "image21");
  GLADE_HOOKUP_OBJECT (window, label44, "label44");
  GLADE_HOOKUP_OBJECT (window, page5_next_button, "page5_next_button");
  GLADE_HOOKUP_OBJECT (window, alignment13, "alignment13");
  GLADE_HOOKUP_OBJECT (window, hbox31, "hbox31");
  GLADE_HOOKUP_OBJECT (window, image22, "image22");
  GLADE_HOOKUP_OBJECT (window, label45, "label45");
  GLADE_HOOKUP_OBJECT (window, admin_etc_backup_checkbutton, "admin_etc_backup_checkbutton");
  GLADE_HOOKUP_OBJECT (window, label47, "label47");
  GLADE_HOOKUP_OBJECT (window, admin_var_backup_checkbutton, "admin_var_backup_checkbutton");
  GLADE_HOOKUP_OBJECT (window, label48, "label48");
  GLADE_HOOKUP_OBJECT (window, label27, "label27");
  GLADE_HOOKUP_OBJECT (window, vbox6, "vbox6");
  GLADE_HOOKUP_OBJECT (window, hbox15, "hbox15");
  GLADE_HOOKUP_OBJECT (window, image12, "image12");
  GLADE_HOOKUP_OBJECT (window, label21, "label21");
  GLADE_HOOKUP_OBJECT (window, label22, "label22");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox5, "hbuttonbox5");
  GLADE_HOOKUP_OBJECT (window, page6_back_button, "page6_back_button");
  GLADE_HOOKUP_OBJECT (window, alignment7, "alignment7");
  GLADE_HOOKUP_OBJECT (window, hbox17, "hbox17");
  GLADE_HOOKUP_OBJECT (window, image13, "image13");
  GLADE_HOOKUP_OBJECT (window, label24, "label24");
  GLADE_HOOKUP_OBJECT (window, page6_next_button, "page6_next_button");
  GLADE_HOOKUP_OBJECT (window, alignment15, "alignment15");
  GLADE_HOOKUP_OBJECT (window, hbox34, "hbox34");
  GLADE_HOOKUP_OBJECT (window, image25, "image25");
  GLADE_HOOKUP_OBJECT (window, label56, "label56");
  GLADE_HOOKUP_OBJECT (window, vbox11, "vbox11");
  GLADE_HOOKUP_OBJECT (window, tar_gz_compression_radiobutton, "tar_gz_compression_radiobutton");
  GLADE_HOOKUP_OBJECT (window, label53, "label53");
  GLADE_HOOKUP_OBJECT (window, zip_compression_radiobutton, "zip_compression_radiobutton");
  GLADE_HOOKUP_OBJECT (window, label54, "label54");
  GLADE_HOOKUP_OBJECT (window, tar_bz2_compression_radiobutton, "tar_bz2_compression_radiobutton");
  GLADE_HOOKUP_OBJECT (window, label55, "label55");
  GLADE_HOOKUP_OBJECT (window, label20, "label20");
  GLADE_HOOKUP_OBJECT (window, vbox10, "vbox10");
  GLADE_HOOKUP_OBJECT (window, hbox32, "hbox32");
  GLADE_HOOKUP_OBJECT (window, image23, "image23");
  GLADE_HOOKUP_OBJECT (window, label50, "label50");
  GLADE_HOOKUP_OBJECT (window, label51, "label51");
  GLADE_HOOKUP_OBJECT (window, hbuttonbox9, "hbuttonbox9");
  GLADE_HOOKUP_OBJECT (window, page7_back_button, "page7_back_button");
  GLADE_HOOKUP_OBJECT (window, alignment14, "alignment14");
  GLADE_HOOKUP_OBJECT (window, hbox33, "hbox33");
  GLADE_HOOKUP_OBJECT (window, image24, "image24");
  GLADE_HOOKUP_OBJECT (window, label52, "label52");
  GLADE_HOOKUP_OBJECT (window, page7_record_button, "page7_record_button");
  GLADE_HOOKUP_OBJECT (window, label49, "label49");

  return window;
}

