#include <gtk/gtk.h>


void
on_window_destroy                      (GtkObject       *object,
                                        gpointer         user_data);

void
on_page0_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page0_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page1_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page1_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page2_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page2_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page3_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page3_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page4_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page4_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page5_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page5_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page6_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page6_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page7_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page7_record_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);
